# urn-data-xz-eticaai

### urnresolver --urn-list

Result of [urnresolver --urn-list](https://github.com/EticaAI/HXL-Data-Science-file-formats/blob/main/hxlm/core/bin/urnresolver.py) on 2021-04-22

```bash
fititnt@bravo:/workspace/git/EticaAI/HXL-Data-Science-file-formats$ urnresolver --urn-list
urn:data:br:saude.gov.br:vacinacao:covid-19-vacinacao
urn:data:xz:hxl:standard:core:hashtag
urn:data:xz:hxl:standard:core:attribute
urn:data:un:locode
urn:data:un:unece:locode
urn:data--i:un:unece:locode
urn:data:xz:hxlcplp:fod:lang

```